==> openshift-model-monitoring-5.10.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/SlackConfirmationFieldFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class SlackConfirmationFieldFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfirmationFieldFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfirmationFieldFluent<A>{
  public SlackConfirmationFieldFluentImpl() {
  }
  public SlackConfirmationFieldFluentImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfirmationField instance) {
    this.withDismissText(instance.getDismissText()); 
    this.withOkText(instance.getOkText()); 
    this.withText(instance.getText()); 
    this.withTitle(instance.getTitle()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String dismissText;
  private java.lang.String okText;
  private java.lang.String text;
  private java.lang.String title;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDismissText() {
    return this.dismissText;
  }
  public A withDismissText(java.lang.String dismissText) {
    this.dismissText=dismissText; return (A) this;
  }
  public java.lang.Boolean hasDismissText() {
    return this.dismissText != null;
  }
  
  /**
   * Method is deprecated. use withDismissText instead.
   */
  @java.lang.Deprecated
  public A withNewDismissText(java.lang.String arg0) {
    return (A)withDismissText(new String(arg0));
  }
  public java.lang.String getOkText() {
    return this.okText;
  }
  public A withOkText(java.lang.String okText) {
    this.okText=okText; return (A) this;
  }
  public java.lang.Boolean hasOkText() {
    return this.okText != null;
  }
  
  /**
   * Method is deprecated. use withOkText instead.
   */
  @java.lang.Deprecated
  public A withNewOkText(java.lang.String arg0) {
    return (A)withOkText(new String(arg0));
  }
  public java.lang.String getText() {
    return this.text;
  }
  public A withText(java.lang.String text) {
    this.text=text; return (A) this;
  }
  public java.lang.Boolean hasText() {
    return this.text != null;
  }
  
  /**
   * Method is deprecated. use withText instead.
   */
  @java.lang.Deprecated
  public A withNewText(java.lang.String arg0) {
    return (A)withText(new String(arg0));
  }
  public java.lang.String getTitle() {
    return this.title;
  }
  public A withTitle(java.lang.String title) {
    this.title=title; return (A) this;
  }
  public java.lang.Boolean hasTitle() {
    return this.title != null;
  }
  
  /**
   * Method is deprecated. use withTitle instead.
   */
  @java.lang.Deprecated
  public A withNewTitle(java.lang.String arg0) {
    return (A)withTitle(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SlackConfirmationFieldFluentImpl that = (SlackConfirmationFieldFluentImpl) o;
    if (dismissText != null ? !dismissText.equals(that.dismissText) :that.dismissText != null) return false;
    if (okText != null ? !okText.equals(that.okText) :that.okText != null) return false;
    if (text != null ? !text.equals(that.text) :that.text != null) return false;
    if (title != null ? !title.equals(that.title) :that.title != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(dismissText,  okText,  text,  title,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/SlackConfirmationFieldFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class SlackConfirmationFieldFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfirmationFieldFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfirmationFieldFluent<A>{
  public SlackConfirmationFieldFluentImpl() {
  }
  public SlackConfirmationFieldFluentImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackConfirmationField instance) {
    this.withDismissText(instance.getDismissText()); 
    this.withOkText(instance.getOkText()); 
    this.withText(instance.getText()); 
    this.withTitle(instance.getTitle()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String dismissText;
  private java.lang.String okText;
  private java.lang.String text;
  private java.lang.String title;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDismissText() {
    return this.dismissText;
  }
  public A withDismissText(java.lang.String dismissText) {
    this.dismissText=dismissText; return (A) this;
  }
  public java.lang.Boolean hasDismissText() {
    return this.dismissText != null;
  }
  
  /**
   * Method is deprecated. use withDismissText instead.
   */
  @java.lang.Deprecated
  public A withNewDismissText(java.lang.String arg0) {
    return (A)withDismissText(new String(arg0));
  }
  public java.lang.String getOkText() {
    return this.okText;
  }
  public A withOkText(java.lang.String okText) {
    this.okText=okText; return (A) this;
  }
  public java.lang.Boolean hasOkText() {
    return this.okText != null;
  }
  
  /**
   * Method is deprecated. use withOkText instead.
   */
  @java.lang.Deprecated
  public A withNewOkText(java.lang.String arg0) {
    return (A)withOkText(new String(arg0));
  }
  public java.lang.String getText() {
    return this.text;
  }
  public A withText(java.lang.String text) {
    this.text=text; return (A) this;
  }
  public java.lang.Boolean hasText() {
    return this.text != null;
  }
  
  /**
   * Method is deprecated. use withText instead.
   */
  @java.lang.Deprecated
  public A withNewText(java.lang.String arg0) {
    return (A)withText(new String(arg0));
  }
  public java.lang.String getTitle() {
    return this.title;
  }
  public A withTitle(java.lang.String title) {
    this.title=title; return (A) this;
  }
  public java.lang.Boolean hasTitle() {
    return this.title != null;
  }
  
  /**
   * Method is deprecated. use withTitle instead.
   */
  @java.lang.Deprecated
  public A withNewTitle(java.lang.String arg0) {
    return (A)withTitle(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SlackConfirmationFieldFluentImpl that = (SlackConfirmationFieldFluentImpl) o;
    if (dismissText != null ? !dismissText.equals(that.dismissText) :that.dismissText != null) return false;
    if (okText != null ? !okText.equals(that.okText) :that.okText != null) return false;
    if (text != null ? !text.equals(that.text) :that.text != null) return false;
    if (title != null ? !title.equals(that.title) :that.title != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(dismissText,  okText,  text,  title,  additionalProperties,  super.hashCode());
  }
  
}
